@@ -33,8 +33,10 @@ class MakefileArmcc(MakefileTool):
         return 'armcc'
 
     def export_project(self):
-        """ Processes misc options specific for GCC ARM, and run generator """
+        """ Processes misc options specific for ARMCC, and run generator """
         generated_projects = deepcopy(self.generated_projects)
         self.process_data_for_makefile(self.workspace)
-        generated_projects['path'], generated_projects['files']['makefile'] = self.gen_file_jinja('makefile_armcc.tmpl', self.workspace, 'Makefile', self.workspace['output_dir']['path'])
+        generated_projects['path'], generated_projects['files']['makefile'] = \
+            self.gen_file_jinja('makefile_armcc.tmpl', self.workspace, 'Makefile',
+                                self.workspace['output_dir']['path'])
         return generated_projects
